@@ -19,12 +19,13 @@ class LIFOCache:
     # This method works in O(1)
     def get(self, key):
         with self.lock:
+            result=-1
             if key in self.map:
                 node = self.map[key]
                 result = node.val
                 return result
             self.verdata.get_data(key,result,self.list.head)
-        return -1
+            return result
 
     # This method works in O(1)
     def set(self, key, value):
